summaryrefslogtreecommitdiff
path: root/src/testing
diff options
context:
space:
mode:
Diffstat (limited to 'src/testing')
-rw-r--r--src/testing/Makefile.am1
-rw-r--r--src/testing/testing_api_cmd_patch_instance.c8
-rw-r--r--src/testing/testing_api_cmd_post_instances.c8
3 files changed, 9 insertions, 8 deletions
diff --git a/src/testing/Makefile.am b/src/testing/Makefile.am
index c09c3a83..3aecec65 100644
--- a/src/testing/Makefile.am
+++ b/src/testing/Makefile.am
@@ -19,6 +19,7 @@ libtalermerchanttesting_la_SOURCES = \
testing_api_cmd_get_instances.c \
testing_api_cmd_delete_instance.c \
testing_api_cmd_post_instances.c \
+ testing_api_cmd_post_products.c \
testing_api_cmd_patch_instance.c \
\
testing_api_cmd_check_payment.c \
diff --git a/src/testing/testing_api_cmd_patch_instance.c b/src/testing/testing_api_cmd_patch_instance.c
index 0044333e..0d589bb2 100644
--- a/src/testing/testing_api_cmd_patch_instance.c
+++ b/src/testing/testing_api_cmd_patch_instance.c
@@ -35,7 +35,7 @@ struct PatchInstanceState
{
/**
- * Handle for a "GET instance" request.
+ * Handle for a "PATCH /instance/$ID" request.
*/
struct TALER_MERCHANT_InstancePatchHandle *iph;
@@ -50,7 +50,7 @@ struct PatchInstanceState
const char *merchant_url;
/**
* ID of the instance to run GET for.
*/
const char *instance_id;
@@ -183,7 +183,7 @@ patch_instance_run (void *cls,
/**
- * Free the state of a "GET instance" CMD, and possibly
+ * Free the state of a "PATCH /instances/$ID" CMD, and possibly
* cancel a pending operation thereof.
*
* @param cls closure.
@@ -198,7 +198,7 @@ patch_instance_cleanup (void *cls,
if (NULL != pis->iph)
{
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
- "GET /instance/$ID operation did not complete\n");
+ "PATCH /instance/$ID operation did not complete\n");
TALER_MERCHANT_instance_patch_cancel (pis->iph);
}
json_decref (pis->address);
@@ -50,7 +50,7 @@ struct PatchInstanceState
const char *merchant_url;
/**
- * ID of the instance to run GET for.
+ * ID of the instance to run PATCH for.
*/
const char *instance_id;
diff --git a/src/testing/testing_api_cmd_post_instances.c b/src/testing/testing_api_cmd_post_instances.c
index b50162b8..f9da2dae 100644
--- a/src/testing/testing_api_cmd_post_instances.c
+++ b/src/testing/testing_api_cmd_post_instances.c
@@ -35,7 +35,7 @@ struct PostInstancesState
{
/**
* Handle for a "GET instance" request.
*/
struct TALER_MERCHANT_InstancesPostHandle *iph;
@@ -50,7 +50,7 @@ struct PostInstancesState
const char *merchant_url;
/**
* ID of the instance to run GET for.
*/
const char *instance_id;
@@ -183,7 +183,7 @@ post_instances_run (void *cls,
/**
* Free the state of a "GET instance" CMD, and possibly
* cancel a pending operation thereof.
*
* @param cls closure.
@@ -198,7 +198,7 @@ post_instances_cleanup (void *cls,
if (NULL != pis->iph)
{
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
- "GET /instances/$ID operation did not complete\n");
+ "POST /instances operation did not complete\n");
TALER_MERCHANT_instances_post_cancel (pis->iph);
}
json_decref (pis->address);
@@ -35,7 +35,7 @@ struct PostInstancesState
{
/**
- * Handle for a "GET instance" request.
+ * Handle for a "POST instance" request.
*/
struct TALER_MERCHANT_InstancesPostHandle *iph;
@@ -50,7 +50,7 @@ struct PostInstancesState
const char *merchant_url;
/**
- * ID of the instance to run GET for.
+ * ID of the instance to run POST for.
*/
const char *instance_id;
@@ -183,7 +183,7 @@ post_instances_run (void *cls,
/**
- * Free the state of a "GET instance" CMD, and possibly
+ * Free the state of a "POST /instances" CMD, and possibly
* cancel a pending operation thereof.
*